==> gnome-terminal-debuginfo-3.14.3-1.tar.xz: usr/src/debug/gnome-terminal-3.14.3-1/src/terminal-type-builtins.c <==

/* Generated data (by glib-mkenums) */

#include <config.h>

#include "terminal-type-builtins.h"

/* enumerations from "/usr/src/ports/gnome-terminal/gnome-terminal-3.14.3-1.i686/src/gnome-terminal-3.14.3/src/terminal-enums.h" */

#include "/usr/src/ports/gnome-terminal/gnome-terminal-3.14.3-1.i686/src/gnome-terminal-3.14.3/src/terminal-enums.h"

GType
terminal_new_terminal_mode_get_type (void)
{
  static volatile gsize g_define_type_id__volatile = 0;
 
  if (g_once_init_enter (&g_define_type_id__volatile)) {
    static const GEnumValue values[] = {
      { TERMINAL_NEW_TERMINAL_MODE_WINDOW, "TERMINAL_NEW_TERMINAL_MODE_WINDOW", "window" },
      { TERMINAL_NEW_TERMINAL_MODE_TAB, "TERMINAL_NEW_TERMINAL_MODE_TAB", "tab" },
      { 0, NULL, NULL }
    };
    GType g_define_type_id = \
       g_enum_register_static (/* g_intern_static_string */ ("TerminalNewTerminalMode"), values);
      
    g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
  }
    
  return g_define_type_id__volatile;
}

GType
terminal_exit_action_get_type (void)
{
  static volatile gsize g_define_type_id__volatile = 0;
 
  if (g_once_init_enter (&g_define_type_id__volatile)) {
    static const GEnumValue values[] = {
      { TERMINAL_EXIT_CLOSE, "TERMINAL_EXIT_CLOSE", "close" },
      { TERMINAL_EXIT_RESTART, "TERMINAL_EXIT_RESTART", "restart" },
      { TERMINAL_EXIT_HOLD, "TERMINAL_EXIT_HOLD", "hold" },
      { 0, NULL, NULL }
    };
    GType g_define_type_id = \
       g_enum_register_static (/* g_intern_static_string */ ("TerminalExitAction"), values);
      
    g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
  }
    
  return g_define_type_id__volatile;
}

GType
terminal_settings_list_flags_get_type (void)
{
  static volatile gsize g_define_type_id__volatile = 0;
 
  if (g_once_init_enter (&g_define_type_id__volatile)) {
    static const GFlagsValue values[] = {
      { TERMINAL_SETTINGS_LIST_FLAG_NONE, "TERMINAL_SETTINGS_LIST_FLAG_NONE", "none" },
      { TERMINAL_SETTINGS_LIST_FLAG_HAS_DEFAULT, "TERMINAL_SETTINGS_LIST_FLAG_HAS_DEFAULT", "has-default" },
      { TERMINAL_SETTINGS_LIST_FLAG_ALLOW_EMPTY, "TERMINAL_SETTINGS_LIST_FLAG_ALLOW_EMPTY", "allow-empty" },
      { 0, NULL, NULL }
    };
    GType g_define_type_id = \
       g_flags_register_static (/* g_intern_static_string */ ("TerminalSettingsListFlags"), values);
      
    g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
  }
    
  return g_define_type_id__volatile;
}

GType
terminal_cjk_width_get_type (void)
{
  static volatile gsize g_define_type_id__volatile = 0;
 
  if (g_once_init_enter (&g_define_type_id__volatile)) {
    static const GEnumValue values[] = {
      { TERMINAL_CJK_WIDTH_NARROW, "TERMINAL_CJK_WIDTH_NARROW", "narrow" },
      { TERMINAL_CJK_WIDTH_WIDE, "TERMINAL_CJK_WIDTH_WIDE", "wide" },
      { 0, NULL, NULL }
    };
    GType g_define_type_id = \
       g_enum_register_static (/* g_intern_static_string */ ("TerminalCJKWidth"), values);
      
    g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
  }
    
  return g_define_type_id__volatile;
}



/* Generated data ends here */

==> gnome-terminal-debuginfo-3.18.2-1.tar.xz: usr/src/debug/gnome-terminal-3.18.2-1/src/terminal-type-builtins.c <==

/* Generated data (by glib-mkenums) */

#include <config.h>

#include "terminal-type-builtins.h"

/* enumerations from "/usr/src/ports/gnome-terminal/gnome-terminal-3.18.2-1.x86_64/src/gnome-terminal-3.18.2/src/terminal-enums.h" */

#include "/usr/src/ports/gnome-terminal/gnome-terminal-3.18.2-1.x86_64/src/gnome-terminal-3.18.2/src/terminal-enums.h"

GType
terminal_new_terminal_mode_get_type (void)
{
  static volatile gsize g_define_type_id__volatile = 0;
 
  if (g_once_init_enter (&g_define_type_id__volatile)) {
    static const GEnumValue values[] = {
      { TERMINAL_NEW_TERMINAL_MODE_WINDOW, "TERMINAL_NEW_TERMINAL_MODE_WINDOW", "window" },
      { TERMINAL_NEW_TERMINAL_MODE_TAB, "TERMINAL_NEW_TERMINAL_MODE_TAB", "tab" },
      { 0, NULL, NULL }
    };
    GType g_define_type_id = \
       g_enum_register_static (/* g_intern_static_string */ ("TerminalNewTerminalMode"), values);
      
    g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
  }
    
  return g_define_type_id__volatile;
}

GType
terminal_exit_action_get_type (void)
{
  static volatile gsize g_define_type_id__volatile = 0;
 
  if (g_once_init_enter (&g_define_type_id__volatile)) {
    static const GEnumValue values[] = {
      { TERMINAL_EXIT_CLOSE, "TERMINAL_EXIT_CLOSE", "close" },
      { TERMINAL_EXIT_RESTART, "TERMINAL_EXIT_RESTART", "restart" },
      { TERMINAL_EXIT_HOLD, "TERMINAL_EXIT_HOLD", "hold" },
      { 0, NULL, NULL }
    };
    GType g_define_type_id = \
       g_enum_register_static (/* g_intern_static_string */ ("TerminalExitAction"), values);
      
    g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
  }
    
  return g_define_type_id__volatile;
}

GType
terminal_settings_list_flags_get_type (void)
{
  static volatile gsize g_define_type_id__volatile = 0;
 
  if (g_once_init_enter (&g_define_type_id__volatile)) {
    static const GFlagsValue values[] = {
      { TERMINAL_SETTINGS_LIST_FLAG_NONE, "TERMINAL_SETTINGS_LIST_FLAG_NONE", "none" },
      { TERMINAL_SETTINGS_LIST_FLAG_HAS_DEFAULT, "TERMINAL_SETTINGS_LIST_FLAG_HAS_DEFAULT", "has-default" },
      { TERMINAL_SETTINGS_LIST_FLAG_ALLOW_EMPTY, "TERMINAL_SETTINGS_LIST_FLAG_ALLOW_EMPTY", "allow-empty" },
      { 0, NULL, NULL }
    };
    GType g_define_type_id = \
       g_flags_register_static (/* g_intern_static_string */ ("TerminalSettingsListFlags"), values);
      
    g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
  }
    
  return g_define_type_id__volatile;
}

GType
terminal_cjk_width_get_type (void)
{
  static volatile gsize g_define_type_id__volatile = 0;
 
  if (g_once_init_enter (&g_define_type_id__volatile)) {
    static const GEnumValue values[] = {
      { TERMINAL_CJK_WIDTH_NARROW, "TERMINAL_CJK_WIDTH_NARROW", "narrow" },
      { TERMINAL_CJK_WIDTH_WIDE, "TERMINAL_CJK_WIDTH_WIDE", "wide" },
      { 0, NULL, NULL }
    };
    GType g_define_type_id = \
       g_enum_register_static (/* g_intern_static_string */ ("TerminalCJKWidth"), values);
      
    g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
  }
    
  return g_define_type_id__volatile;
}



/* Generated data ends here */
